@@ -1,4 +1,6 @@
-from typing import Callable, List, Optional, Tuple
+from __future__ import annotations
+
+from collections.abc import Callable
 
 import pytest
 
@@ -6,7 +8,7 @@ from streamlink.plugin.plugin import Matcher
 from tests.plugins import PluginCanHandleUrl
 
 
-def pytest_collection_modifyitems(items: List[pytest.Item]):  # pragma: no cover
+def pytest_collection_modifyitems(items: list[pytest.Item]):  # pragma: no cover
     # remove empty parametrized tests
     items[:] = [
         item
@@ -21,13 +23,13 @@ def pytest_collection_modifyitems(items: List[pytest.Item]):  # pragma: no cover
 def pytest_generate_tests(metafunc: pytest.Metafunc):
     if metafunc.cls is not None and issubclass(metafunc.cls, PluginCanHandleUrl):
         name: str = f"_parametrize_plugincanhandleurl_{metafunc.function.__name__}"
-        parametrizer: Optional[Callable[[pytest.Metafunc], None]] = globals().get(name)
+        parametrizer: Callable[[pytest.Metafunc], None] | None = globals().get(name)
         if parametrizer:
             parametrizer(metafunc)
 
 
 def _parametrize_plugincanhandleurl_test_all_matchers_match(metafunc: pytest.Metafunc):
-    matchers: List[Tuple[int, Matcher]] = list(enumerate(metafunc.cls.matchers()))
+    matchers: list[tuple[int, Matcher]] = list(enumerate(metafunc.cls.matchers()))
     metafunc.parametrize(
         "matcher",
         [m for i, m in matchers],
@@ -36,7 +38,7 @@ def _parametrize_plugincanhandleurl_test_all_matchers_match(metafunc: pytest.Met
 
 
 def _parametrize_plugincanhandleurl_test_all_named_matchers_have_tests(metafunc: pytest.Metafunc):
-    matchers: List[Matcher] = [m for m in metafunc.cls.matchers() if m.name is not None]
+    matchers: list[Matcher] = [m for m in metafunc.cls.matchers() if m.name is not None]
     metafunc.parametrize(
         "matcher",
         matchers,
