@@ -6,7 +6,7 @@ class TestPluginCanHandleUrlApp17(PluginCanHandleUrl):
     __plugin__ = App17
 
     should_match = [
-        "https://17.live/en-US/live/123123"
+        "https://17.live/en-US/live/123123",
         "https://17.live/en/live/123123",
         "https://17.live/ja/live/123123",
     ]
