@@ -7,12 +7,17 @@ class TestPluginCanHandleUrlNOS(PluginCanHandleUrl):
 
     should_match = [
         "https://nos.nl/live",
-        "https://nos.nl/collectie/13781/livestream/2385081-ek-voetbal-engeland-schotland",
+        "https://nos.nl/livestream/2539164-schaatsen-wb-milwaukee-straks-de-massastart-m",
         "https://nos.nl/collectie/13951/video/2491092-dit-was-prinsjesdag",
+        "https://nos.nl/l/2490788",
         "https://nos.nl/video/2490788-meteoor-gespot-boven-noord-nederland",
     ]
 
     should_not_match = [
+        "https://nos.nl/livestream",
+        "https://nos.nl/l",
+        "https://nos.nl/video",
+        "https://nos.nl/collectie",
         "https://nos.nl/artikel/2385784-explosieve-situatie-leidde-tot-verwoeste-huizen-en-omgewaaide-bomen-leersum",
         "https://nos.nl/sport",
         "https://nos.nl/sport/videos",
