@@ -1,4 +1,3 @@
-import codecs
 import os.path
 from contextlib import contextmanager
 from io import BytesIO
@@ -28,11 +27,11 @@ def _parse_xml(data, strip_ns=False):
 
 @contextmanager
 def text(path, encoding="utf8"):
-    with codecs.open(os.path.join(__here__, path), "r", encoding=encoding) as resource_fh:
+    with open(os.path.join(__here__, path), "r", encoding=encoding) as resource_fh:
         yield resource_fh
 
 
 @contextmanager
 def xml(path, encoding="utf8"):
-    with codecs.open(os.path.join(__here__, path), "r", encoding=encoding) as resource_fh:
+    with open(os.path.join(__here__, path), "r", encoding=encoding) as resource_fh:
         yield _parse_xml(resource_fh.read(), strip_ns=True)
