@@ -1,8 +1,6 @@
 from __future__ import annotations
 
 import logging
-import os
-import sys
 import warnings
 from collections.abc import Iterable
 from datetime import timezone
@@ -47,26 +45,25 @@ def log(request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch, output:
     if "logfile" in request.fixturenames:
         params["filename"] = request.getfixturevalue("logfile")
 
-    stream: TextIOWrapper | None = output
-    if not params.pop("stdout", True):
-        stream = None
-    if not params.pop("stderr", True):
-        monkeypatch.setattr("sys.stderr", None)
-
     fakeroot = logging.getLogger("streamlink.test")
 
     monkeypatch.setattr("streamlink.logger.root", fakeroot)
     monkeypatch.setattr("streamlink.utils.times.LOCAL", timezone.utc)
 
+    stream: TextIOWrapper | None = output if params.pop("stream", True) else None
     handler = logger.basicConfig(stream=stream, **params)
-    assert isinstance(handler, logging.StreamHandler)
+    if stream is None:
+        assert handler is None
+    else:
+        assert isinstance(handler, logging.StreamHandler)
 
     yield fakeroot
 
     logger.capturewarnings(False)
 
-    handler.close()
-    fakeroot.removeHandler(handler)
+    if handler:
+        handler.close()
+        fakeroot.removeHandler(handler)
     assert not fakeroot.handlers
 
 
@@ -279,27 +276,9 @@ class TestLogging:
         assert getvalue(output) == "[test][info] Bär: 🐻\n"
         assert getvalue(output_ascii) == "[test][info] B\\xe4r: \\U0001f43b\n"
 
-    @pytest.mark.parametrize(
-        "log",
-        [pytest.param({"stdout": False}, id="no-stdout")],
-        indirect=["log"],
-    )
-    def test_no_stdout(self, log: logging.Logger):
-        assert log.handlers
-        handler = log.handlers[0]
-        assert isinstance(handler, logging.StreamHandler)
-        assert handler.stream is sys.stderr
-
-    @pytest.mark.parametrize(
-        "log",
-        [pytest.param({"stdout": False, "stderr": False}, id="no-stdout-no-stderr")],
-        indirect=["log"],
-    )
-    def test_no_stdout_no_stderr(self, log: logging.Logger):
-        assert log.handlers
-        handler = log.handlers[0]
-        assert isinstance(handler, logging.FileHandler)
-        assert handler.stream.name.endswith(os.devnull)
+    @pytest.mark.parametrize("log", [pytest.param({"stream": None}, id="no-stdout")], indirect=["log"])
+    def test_no_stream(self, log: logging.Logger):
+        assert not log.handlers
 
     @pytest.mark.parametrize(
         "errno",
